@@ -73,7 +73,7 @@ def filter_source(source):
     for before, after in FILTER:
         s = s.replace(before, after)
     
-    print s
+    print(s)
 
 if __name__ == '__main__':
     import sys
