@@ -15,7 +15,6 @@
  */
 
 #include "qchstyle.h"
-#include "qchtheme.h"
 #include <QMaemo5Style>
 
 /*!
@@ -27,10 +26,8 @@
     \note Style is a context property and cannot be created in QML.
 */
 QchStyle::QchStyle(QObject *parent) :
-    QObject(parent),
-    m_theme(new QchTheme(this))
+    QObject(parent)
 {
-    connect(m_theme, SIGNAL(changed()), this, SIGNAL(changed()));
 }
 
 /*!
@@ -124,6 +121,13 @@ qreal QchStyle::disabledOpacity() {
     return 0.3;
 }
 
+/*!
+    \brief Font family constant.
+*/
+QString QchStyle::fontFamily() {
+    return QFont().family();
+}
+
 /*!
     \brief Default text color constant.
 */
